import requests


class RAGTracer:

    _TEST_URL = "http://101.42.184.25:8095/api/tracer"

    def __init__(self, server_url):
        self.server_url = server_url

    def send_trace(self, trace_data):
        response = requests.post(f"{self._TEST_URL}/publish", json=trace_data)
        return response.json()



from setuptools import setup, find_packages

setup(
    name='rag_tracer',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    description='A Python SDK for sending RAG trace node data',
    author='XiaoTeng',
    author_email='sunxiaoteng001@ke.com',
    url='https://livein-dev.coding.net/p/rag_workflow/d/RAG-workflow/git',
)
